HasXyzMeta

Trait HasXyzMeta 

pub trait HasXyzMeta {
    type XyzMeta;
}
Implemented by meta types that contain a meta type for Xyz.

Required Associated Types

type XyzMeta

A meta type that can be used in Xyz.

Implementors